@@ -94,6 +94,27 @@ public class DetailsStatus extends Document {
     return this.advertisedBandwidth;
   }
 
+  private long overloadGeneralTimestamp;
+
+  public void setOverloadGeneralTimestamp(long overloadGeneralTimestamp) {
+    this.overloadGeneralTimestamp = overloadGeneralTimestamp;
+  }
+
+  public long getOverloadGeneralTimestamp() {
+    return this.overloadGeneralTimestamp;
+  }
+
+  /**
+   * Returns true if the node is overloaded.
+   */
+  public Boolean isOverloadStatus() {
+    if (this.overloadGeneralTimestamp != -1L) {
+      return true;
+    } else {
+      return false;
+    }
+  }
+
   private List<String> exitPolicy;
 
   public void setExitPolicy(List<String> exitPolicy) {
@@ -273,6 +294,17 @@ public class DetailsStatus extends Document {
     return bridgedbDistributor;
   }
 
+  private List<String> blocklist;
+
+  public void setBlocklist(List<String> blocklist) {
+    this.blocklist = (blocklist != null && !blocklist.isEmpty())
+        ? blocklist : null;
+  }
+
+  public List<String> getBlocklist() {
+    return this.blocklist;
+  }
+
   /** Returns all addresses used for the onion-routing protocol which
    * includes the primary address and all additionally configured
    * onion-routing addresses. */
@@ -650,4 +682,3 @@ public class DetailsStatus extends Document {
     return this.versionStatus;
   }
 }
-
