@@ -8,7 +8,8 @@ import org.slf4j.LoggerFactory;
 
 public class UpdateStatus extends Document {
 
-  private static Logger log = LoggerFactory.getLogger(UpdateStatus.class);
+  private static final Logger logger = LoggerFactory.getLogger(
+      UpdateStatus.class);
 
   private long updatedMillis;
 
@@ -25,7 +26,7 @@ public class UpdateStatus extends Document {
     try {
       this.updatedMillis = Long.parseLong(documentString.trim());
     } catch (NumberFormatException e) {
-      log.error("Could not parse timestamp '{}'. Setting to 1970-01-01 "
+      logger.error("Could not parse timestamp '{}'. Setting to 1970-01-01 "
           + "00:00:00.", documentString);
       this.updatedMillis = 0L;
     }
