@@ -30,7 +30,7 @@ import javax.servlet.ServletContextListener;
 
 public class NodeIndexer implements ServletContextListener, Runnable {
 
-  private static final Logger log = LoggerFactory.getLogger(
+  private static final Logger logger = LoggerFactory.getLogger(
       NodeIndexer.class);
 
   @Override
@@ -38,7 +38,7 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     File outDir = new File(System.getProperty("onionoo.basedir",
         "/srv/onionoo.torproject.org/onionoo"), "out");
     if (!outDir.exists() || !outDir.isDirectory()) {
-      log.error("\n\n\tOut-dir not found! Expected directory: {}"
+      logger.error("\n\n\tOut-dir not found! Expected directory: {}"
           + "\n\tSet system property 'onionoo.basedir'.", outDir);
       System.exit(1);
     }
@@ -115,7 +115,7 @@ public class NodeIndexer implements ServletContextListener, Runnable {
         }
       }
     } catch (Throwable th) { // catch all and log
-      log.error("Indexing failed: {}", th.getMessage(), th);
+      logger.error("Indexing failed: {}", th.getMessage(), th);
     }
   }
 
@@ -167,6 +167,12 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     Map<Boolean, Set<String>> newBridgesByRecommendedVersion = new HashMap<>();
     newBridgesByRecommendedVersion.put(true, new HashSet<>());
     newBridgesByRecommendedVersion.put(false, new HashSet<>());
+    Map<Boolean, Set<String>> newRelaysByOverloadStatus = new HashMap<>();
+    newRelaysByOverloadStatus.put(true, new HashSet<>());
+    newRelaysByOverloadStatus.put(false, new HashSet<>());
+    Map<Boolean, Set<String>> newBridgesByOverloadStatus = new HashMap<>();
+    newBridgesByOverloadStatus.put(true, new HashSet<>());
+    newBridgesByOverloadStatus.put(false, new HashSet<>());
     SortedMap<Integer, Set<String>> newRelaysByFirstSeenDays = new TreeMap<>();
     SortedMap<Integer, Set<String>> newBridgesByFirstSeenDays = new TreeMap<>();
     SortedMap<Integer, Set<String>> newRelaysByLastSeenDays = new TreeMap<>();
@@ -299,6 +305,11 @@ public class NodeIndexer implements ServletContextListener, Runnable {
         newRelaysByRecommendedVersion.get(recommendedVersion).add(
             hashedFingerprint);
       }
+      Boolean overloadStatus = entry.isOverloadStatus();
+      if (null != overloadStatus) {
+        newRelaysByOverloadStatus.get(overloadStatus).add(
+            hashedFingerprint);
+      }
     }
     /* This loop can go away once all Onionoo services had their hourly
      * updater write effective families to summary documents at least
@@ -369,6 +380,13 @@ public class NodeIndexer implements ServletContextListener, Runnable {
         newBridgesByRecommendedVersion.get(recommendedVersion).add(
             hashedHashedFingerprint);
       }
+      Boolean overloadStatus = entry.isOverloadStatus();
+      if (null != overloadStatus) {
+        newBridgesByOverloadStatus.get(overloadStatus).add(
+            hashedFingerprint);
+        newBridgesByOverloadStatus.get(overloadStatus).add(
+            hashedHashedFingerprint);
+      }
     }
     NodeIndex newNodeIndex = new NodeIndex();
     newNodeIndex.setRelayFingerprintSummaryLines(
@@ -395,6 +413,8 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     newNodeIndex.setRelaysByHostName(newRelaysByHostName);
     newNodeIndex.setRelaysByRecommendedVersion(newRelaysByRecommendedVersion);
     newNodeIndex.setBridgesByRecommendedVersion(newBridgesByRecommendedVersion);
+    newNodeIndex.setRelaysByOverloadStatus(newRelaysByOverloadStatus);
+    newNodeIndex.setBridgesByOverloadStatus(newBridgesByOverloadStatus);
     synchronized (this) {
       this.lastIndexed = updateStatusMillis;
       this.latestNodeIndex = newNodeIndex;
@@ -402,4 +422,3 @@ public class NodeIndexer implements ServletContextListener, Runnable {
     }
   }
 }
-
