@@ -61,6 +61,36 @@ public class BandwidthStatusTest {
       return this.intervalLength;
     }
 
+    private long overloadRatelimitsTimestamp;
+
+    public long getOverloadRatelimitsTimestamp() {
+      return this.overloadRatelimitsTimestamp;
+    }
+
+    private long overloadRatelimitsRateLimit;
+
+    public long getOverloadRatelimitsRateLimit() {
+      return this.overloadRatelimitsRateLimit;
+    }
+
+    private long overloadRatelimitsBurstLimit;
+
+    public long getOverloadRatelimitsBurstLimit() {
+      return this.overloadRatelimitsBurstLimit;
+    }
+
+    private int overloadRatelimitsReadCount;
+
+    public int getOverloadRatelimitsReadCount() {
+      return this.overloadRatelimitsReadCount;
+    }
+
+    private int overloadRatelimitsWriteCount;
+
+    public int getOverloadRatelimitsWriteCount() {
+      return this.overloadRatelimitsWriteCount;
+    }
+
     private SortedMap<Long, Long> bandwidthValues = new TreeMap<>();
 
     public SortedMap<Long, Long> getBandwidthValues() {
@@ -108,6 +138,38 @@ public class BandwidthStatusTest {
         bandwidthStatus.toDocumentString());
   }
 
+  @Test()
+  public void testExistingStatusWithOverloadRatelimits() {
+    BandwidthStatus bandwidthStatus = new BandwidthStatus();
+    String existingLines =
+        "w 2014-07-31 23:52:22 2014-08-01 00:07:22 4096\n"
+        + "w 2014-08-01 00:07:22 2014-08-01 00:22:22 30720\n"
+        + "rl 2021-08-05 13:00:00 1310720 1310720 360 531\n";
+    bandwidthStatus.setFromDocumentString(existingLines);
+    assertEquals("",
+        existingLines,
+        bandwidthStatus.toDocumentString());
+  }
+
+  @Test()
+  public void testExistingStatusWithoutNewOverloadRatelimits() {
+    BandwidthStatus bandwidthStatus = new BandwidthStatus();
+    String existingLines =
+        "w 2014-07-31 23:52:22 2014-08-01 00:07:22 4096\n"
+        + "w 2014-08-01 00:07:22 2014-08-01 00:22:22 30720\n"
+        + "rl 2021-08-05 13:00:00 1310720 1310720 360 531\n";
+    bandwidthStatus.setFromDocumentString(existingLines);
+    bandwidthStatus.setOverloadRatelimitsTimestamp(-1L);
+    bandwidthStatus.setOverloadRatelimitsRateLimit(-1L);
+    bandwidthStatus.setOverloadRatelimitsBurstLimit(-1L);
+    bandwidthStatus.setOverloadRatelimitsReadCount(-1L);
+    bandwidthStatus.setOverloadRatelimitsWriteCount(-1L);
+    assertEquals("",
+        "w 2014-07-31 23:52:22 2014-08-01 00:07:22 4096\n"
+        + "w 2014-08-01 00:07:22 2014-08-01 00:22:22 30720\n",
+        bandwidthStatus.toDocumentString());
+  }
+
   @Test()
   public void testCompressRecentIntervals() {
     BandwidthStatus bandwidthStatus = new BandwidthStatus();
@@ -144,4 +206,3 @@ public class BandwidthStatusTest {
         statusLines, bandwidthStatus.toDocumentString());
   }
 }
-
