@@ -10,11 +10,10 @@ import org.slf4j.LoggerFactory;
 
 import java.text.SimpleDateFormat;
 import java.util.Collection;
-import java.util.TimeZone;
 
 public class PerformanceMetrics {
 
-  private static final Logger log = LoggerFactory.getLogger(
+  private static final Logger logger = LoggerFactory.getLogger(
       PerformanceMetrics.class);
 
   private static final Object lock = new Object();
@@ -64,20 +63,24 @@ public class PerformanceMetrics {
           > LOG_INTERVAL_MILLIS) {
         SimpleDateFormat dateTimeFormat = new SimpleDateFormat(
             "yyyy-MM-dd HH:mm:ss");
-        dateTimeFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
-        log.info("Request statistics ({}, {} s):",
+        logger.info("Request statistics ({}, {} s):",
             dateTimeFormat.format(lastLoggedMillis + LOG_INTERVAL_MILLIS),
             LOG_INTERVAL_SECONDS);
-        log.info("  Total processed requests: {}", totalProcessedRequests);
-        log.info("  Most frequently requested resource: {}",
+        logger.info("  Total processed requests: {}", totalProcessedRequests);
+        logger.info("  Most frequently requested resource: {}",
             requestsByResourceType);
-        log.info("  Most frequently requested parameter combinations: {}",
+        logger.info("  Most frequently requested parameter combinations: {}",
             requestsByParameters);
-        log.info("  Matching relays per request: {}", matchingRelayDocuments);
-        log.info("  Matching bridges per request: {}", matchingBridgeDocuments);
-        log.info("  Written characters per response: {}", writtenChars);
-        log.info("  Milliseconds to handle request: {}", handleRequestMillis);
-        log.info("  Milliseconds to build response: {}", buildResponseMillis);
+        logger.info("  Matching relays per request: {}",
+            matchingRelayDocuments);
+        logger.info("  Matching bridges per request: {}",
+            matchingBridgeDocuments);
+        logger.info("  Written characters per response: {}",
+            writtenChars);
+        logger.info("  Milliseconds to handle request: {}",
+            handleRequestMillis);
+        logger.info("  Milliseconds to build response: {}",
+            buildResponseMillis);
         totalProcessedRequests.clear();
         requestsByResourceType.clear();
         requestsByParameters.clear();
@@ -94,7 +97,7 @@ public class PerformanceMetrics {
       totalProcessedRequests.increment();
       long handlingTime = parsedRequestMillis - receivedRequestMillis;
       if (handlingTime > DateTimeHelper.ONE_SECOND) {
-        log.warn("longer request handling: {} ms for {} params: {} and {} "
+        logger.warn("longer request handling: {} ms for {} params: {} and {} "
             + "chars.", handlingTime, resourceType, parameterKeys,
             charsWritten);
       }
@@ -106,7 +109,7 @@ public class PerformanceMetrics {
       writtenChars.addLong(charsWritten);
       long responseTime = writtenResponseMillis - parsedRequestMillis;
       if (responseTime > DateTimeHelper.ONE_SECOND) {
-        log.warn("longer response building: {} ms for {} params: {} and {} "
+        logger.warn("longer response building: {} ms for {} params: {} and {} "
             + "chars.", responseTime, resourceType, parameterKeys,
             charsWritten);
       }
