@@ -19,7 +19,7 @@ import java.util.SortedSet;
 
 public class SummaryDocumentWriter implements DocumentWriter {
 
-  private static final Logger log = LoggerFactory.getLogger(
+  private static final Logger logger = LoggerFactory.getLogger(
       SummaryDocumentWriter.class);
 
   private DocumentStore documentStore;
@@ -98,17 +98,18 @@ public class SummaryDocumentWriter implements DocumentWriter {
       SortedSet<String> unverifiedHostNames =
           nodeStatus.getUnverifiedHostNames();
       Boolean recommendedVersion = nodeStatus.isRecommendedVersion();
+      Boolean overloadStatus = nodeStatus.isOverloadStatus();
       SummaryDocument summaryDocument = new SummaryDocument(isRelay,
           nickname, fingerprint, addresses, lastSeenMillis, running,
           relayFlags, consensusWeight, countryCode, firstSeenMillis,
           asNumber, asName, contact, declaredFamily, effectiveFamily, version,
           operatingSystem, verifiedHostNames,
-          unverifiedHostNames, recommendedVersion);
+          unverifiedHostNames, recommendedVersion, overloadStatus);
       if (this.documentStore.store(summaryDocument, fingerprint)) {
         this.writtenDocuments++;
       }
     }
-    log.info("Wrote summary document files");
+    logger.info("Wrote summary document files");
   }
 
   @Override
@@ -119,4 +120,3 @@ public class SummaryDocumentWriter implements DocumentWriter {
         FormattingUtils.formatDecimalNumber(this.deletedDocuments));
   }
 }
-
